;-------------------------------------------------------------
;+
; NAME:
;       FIND_DATUM
; PURPOSE:
;       This routine a result-matrix for max./min. value by given time
; MAIN PROGRAM:
;       SLAP - program for testing SEISMOLAP 
;       SEISMOLAP was developed by Jochen Zschau,
;       Geoforschungszentrum Potsdam, Germany
; DEPENDENCIES:
;       GET_TIME.PRO
; MODIFICATION HISTORY:
;       Matthias Liebetanz, TU-Darmstadt, Germany, 17 Apr, 1998.
;       No warranty that this program is free of error
;-
;-------------------------------------------------------------
FUNCTION FIND_DATUM, PATH = path                                   
      
           
answer = 0          
          
file = PICKFILE(TITLE='Open File',$                   ; Get name of data-file              
                     FILTER='*.sav',$              
                      PATH=path,$              
                       GET_PATH=path)              
          
IF file EQ '' THEN RETURN, 0                           ; 'Cancel' was pressed              
          
         
RESTORE,file               
               
         
IF NOT DEFINED(im) THEN BEGIN               
               
       IF NOT DEFINED(data) THEN BEGIN               
          mess=WIDGET_MESSAGE('No data!',/ERROR)               
          RETURN,0           
       ENDIF               
           
       time = GET_TIME ( epoches(0), $    
                         MINIMUM=minimum )      
      
       IF time(0) EQ -1 THEN RETURN,0      
            
       timediff=ABS(time-epoches)       
        
       min_timediff = MIN(timediff)       
       
       itime = WHERE ( timediff EQ min_timediff )       
            
       IF KEYWORD_SET(MINIMUM) THEN BEGIN           
                     
          extremum = MIN ( data( *,*,*,itime) )           
               
          searchtype = 'minimum'           
           
       ENDIF ELSE BEGIN           
                     
          extremum = MAX ( data ( *,*,*,itime) )               
           
          searchtype = 'maximum'           
           
       ENDELSE           
       
       result = WHERE ( data( *,*,*,itime) EQ extremum )           
                  
       tmp = WIDGET_MESSAGE([['Press Ok to choose'], $         
                             ['the result file']], $              
                            /INFORMATION )              
                 
       orifile = file              
                 
       file = PICKFILE(/WRITE, $              
               PATH=path, $              
               FILE=path+STRTRUNC(FPRAEFIX(file,/NO_PATH),5,0)+'.txt', $              
               FILTER='*.txt',$              
               GET_PATH=path)              
              
       IF file EQ '' THEN RETURN, 0                 ; 'Cancel' was pressed              
                 
       IF N_ELEMENTS(data(*,*,0,*)) EQ N_ELEMENTS(epoches) THEN BEGIN               
               
             OPENW,unit,file,/GET_LUN               
             PRINTF,unit,'Results for time search:'               
             PRINTF,unit,'==========================='               
             PRINTF,unit,'File:            ', orifile               
             PRINTF,unit,'Mode: Point mode'               
             PRINTF,unit,'Longitude [deg]: ',STRTRIM(STRING(lon(0)),1)               
             PRINTF,unit,'Latitude [deg]:  ',STRTRIM(STRING(lat(0)),1)               
             PRINTF,unit,'Depth [m]:       ',STRTRIM(STRING(MIN(z)),1)               
             PRINTF,unit,'Min. epoche :               ',dt_tm_fromjs(t(0),FORMAT='0d$.n$.Y$ h$:m$:s$')             
             PRINTF,unit,'Max. epoche :               ',dt_tm_fromjs(t(1),FORMAT='0d$.n$.Y$ h$:m$:s$')             
             PRINTF,unit,'Time window:                ',strsec(timewin)               
             PRINTF,unit,'Time shift:                 ',strsec(shift)               
             PRINTF,unit               
             PRINTF,unit,'Nearest Epoche found:          ',dt_tm_fromjs(epoches(itime),FORMAT='0d$.n$.Y$ h$:m$:s$')               
             PRINTF,unit,  + ' found:'               
             PRINTF,unit,'Value : ',STRTRIM ( STRING( extremum ) , 1 )               
               
       ENDIF ELSE BEGIN               
               
             OPENW,unit,file,/GET_LUN               
             PRINTF,unit,'Results for ' + searchtype + ' search:'               
             PRINTF,unit,'==========================='               
             PRINTF,unit,'File:                       ', orifile               
             PRINTF,unit,'Mode: Grid mode'               
             PRINTF,unit,'Min./ max. longitude [deg]: ',STRTRIM(STRING(lon(0)),1),' / ',STRTRIM(STRING(lon(1)),1)               
             PRINTF,unit,'Min./ max. latitude [deg]:  ',STRTRIM(STRING(lat(0)),1),' / ',STRTRIM(STRING(lat(1)),1)               
             PRINTF,unit,'Min./ max. depth [m]:       ',STRTRIM(STRING(MIN(z)),1),' / ',STRTRIM(STRING(MAX(z)),1)               
             PRINTF,unit,'Grid-spacing [deg]:         ',STRTRIM(STRING(spacing),1)               
             PRINTF,unit,'Depth-spacing [m]:          ',STRTRIM(STRING(z_spacing),1)               
             PRINTF,unit,'Min. epoche :               ',dt_tm_fromjs(t(0),FORMAT='0d$.n$.Y$ h$:m$:s$')               
             PRINTF,unit,'Max. epoche :               ',dt_tm_fromjs(t(1),FORMAT='0d$.n$.Y$ h$:m$:s$')               
             PRINTF,unit,'Time window:                ',strsec(timewin)               
             PRINTF,unit,'Time shift:                 ',strsec(shift)               
             PRINTF,unit               
             PRINTF,unit,'Nearest Epoche found:          ',dt_tm_fromjs(epoches(itime),FORMAT='0d$.n$.Y$ h$:m$:s$')               
             PRINTF,unit, searchtype + ' found at:'               
             longitude = result - FLOOR( result / n_lon ) * n_lon               
             longitude = longitude * spacing + lon(0)               
             longitude = STRTRIM ( STRING( longitude ), 1 )               
             PRINTF,unit,'Longitude [deg]:  ', longitude               
             latitude = result - FLOOR( result / ( n_lat * n_lon ) ) * n_lon * n_lat               
             latitude = FLOOR( latitude / n_lon ) * spacing + lat(0)               
             latitude = STRTRIM ( STRING( latitude ) , 1 )               
             PRINTF,unit,'Latitude [deg]:   ', latitude               
             depth = result - FLOOR( result / ( n_lat * n_lon * n_z ) ) * n_lat * n_lon * n_z               
             depth = FLOOR( depth / ( n_lon * n_lat ) ) * z_spacing + z(0)               
             depth = STRTRIM ( STRING( depth ) , 1 )               
             PRINTF,unit,'Depth [m]:        ', depth               
             PRINTF,unit,'Value : ',STRTRIM ( STRING( extremum ) , 1 )               
               
       ENDELSE               
               
       FREE_LUN,unit               
           
       answer = 1          
                 
       yn = XDECISION('Do You want to see the results now ?')              
       IF STRUPCASE(yn) EQ 'Y' THEN XDISPLAYFILE, file              
              
ENDIF         
          
          
           
RETURN, answer           
           
END           
           
           
