;-------------------------------------------------------------
;+
; NAME:
;       FLINES
; PURPOSE:
;       Determines the number of lines in a formatted file. Can optionally set
;       the pointer on an specified point of the file.
; CATEGORY:
;       I/O
; CALLING SEQUENCE:
;       result = flines(f_name=f_name [or] unit=unit[,search=search][,repeat=repeat][,/f_close])
; INPUTS:
;       unit = unit number of the file
;       str = string to be searched in the file
;       repeat = Number of occurences of 'str' to ignore
;       f_name = a string containing the name of the file to be open
; KEYWORD PARAMETERS:
;       UNIT = unit-Number of an already opened file
;       STR = 'result' will be the number of lines until 'str' is found.
;       REPEAT = Number of occurences of 'str' to ignore.
;       F_NAME = If this Keyword is set, the file will be opened.
;       F_CLOSE = The file is closed at the end
; OUTPUTS:
;       unit = unit number of the file specified by the file.
;       result = array: result(0) = unit number from OPENR,F_NAME,GET_LUN=UNIT
;                       result(1) = Number of lines
;                       result(2) = -1, if an error eccurs
;                                   1, if no error occurs
; NOTES:
;       Works only with formatted files.
; MODIFICATION HISTORY:
;       Matthias Liebetanz, TU-Darmstadt, Germany, 5 Apr, 1997
;
;       No warranty that this program is free of error
;-
;-------------------------------------------------------------

FUNCTION FLINES, UNIT=unit, STR=str, RPEAT=rpeat, F_NAME=f_name, F_CLOSE=F_CLOSE

result= INTARR(3)

IF NOT (KEYWORD_SET(UNIT) OR KEYWORD_SET(F_NAME)) THEN BEGIN
PRINT,'You have to specify a unit-number or a filename (with: F_NAME=["filename"]).'
result(2)=-1
RETURN,result
ENDIF

IF KEYWORD_SET(F_NAME) THEN BEGIN
   OPENR, unit, f_name, /GET_LUN, ERROR=i                       ; open the file and check for i/o-error
   IF i lt 0 THEN BEGIN                                                             ; OK?
      mssg = WIDGET_MESSAGE(STRING(!err_string) $        ; NO
                            +' Can not read '+f_name,/ERROR)
      return = -1
   ENDIF
ENDIF

IF KEYWORD_SET(STR) THEN BEGIN
   IF KEYWORD_SET(RPEAT) THEN BEGIN
      occ_str=-1  &  n_occ=0   &  lines=0  &  tmp=''                             ; Initialize
      WHILE (NOT EOF(unit)) AND (occ_str EQ -1) DO BEGIN
             READF,unit, tmp, $                               ; Read current line in tmp
             FORMAT='(A)'
             occ_str=STRPOS(tmp,str)                        ; str is searched in current line
             IF (n_occ LT rpeat) AND (occ_str NE -1) THEN BEGIN      ; str detected
                 occ_str=-1
                 n_occ=n_occ+1                                   ; increment number of occurences
             ENDIF
             lines=lines+1
       ENDWHILE
       IF KEYWORD_SET(F_CLOSE) THEN FREE_LUN, unit
       result(0)=unit  &  result(1)=lines  &  result(2)=1
       RETURN,result
   ENDIF ELSE BEGIN                                  ; Just Keyw. str is set
      occ_str=-1   &   lines=0   &   tmp=''             ; Initialize
      WHILE (NOT EOF(unit)) AND (occ_str EQ -1) DO BEGIN
             READF,unit, tmp, $                               ; Read current line in tmp
             FORMAT='(A)'
             occ_str=STRPOS(tmp,'str')                        ; str is searched in current line
             lines=lines+1
      ENDWHILE
   ENDELSE
   IF KEYWORD_SET(F_CLOSE) THEN FREE_LUN, unit
   result(0)=unit  &  result(1)=lines  &  result(2)=1
   RETURN,result
ENDIF ELSE BEGIN                                     ; No Keyword STR is set, default is
                                                   ; to count all lines
   lines = 0
   WHILE (NOT EOF(unit)) DO BEGIN
         READF,unit,FORMAT='(/)'
         lines=lines+1                                  ; Count lines of file
   ENDWHILE
   IF KEYWORD_SET(F_CLOSE) THEN FREE_LUN, unit
   result(0)=unit  &  result(1)=lines  &  result(2)=1
   RETURN,result
ENDELSE
END
