;-------------------------------------------------------------
;+
; NAME:
;       PPEARS3
; PURPOSE:
;       Calculates the probability (Pearson type 3 distribution)
; MAIN PROGRAM:
;       SLAP - program for testing SEISMOLAP
;       SEISMOLAP was developed by Jochen Zschau,
;       Geoforschungszentrum Potsdam, Germany
; MODIFICATION HISTORY:
;       Matthias Liebetanz, TH-Darmstadt, Germany, 17. Apr 1998 .
;
;       No warranty that this program is free of error
;-
;-------------------------------------------------------------
PRO PPEARS3, x, timewin, timeshift, prob

prob(*) = 0.

n_prob = N_ELEMENTS(x)

n_time = FLOOR (timewin / timeshift)

FOR i = 0L,n_prob-1 - 3 * n_time  DO BEGIN

    i_last = FLOOR (i + 3 * n_time)

    result = MOMENT ( x ( i : i_last - 1) )

    mean_x = result ( 0 )

    var = result ( 1)

    skew = result ( 2 )

    p = ( 2.0D / skew ) ^ 2

    beta = SQRT ( var / p )

    alpha = mean_x - p * beta

    b =  (x(i_last - 1)-alpha)/beta

    IF ( b GE 0 ) THEN BEGIN

       prob ( i_last ) =  - 1 / IGAMMA ( p,b )

    ENDIF ELSE BEGIN

       prob ( i_last ) = 0.

    END

ENDFOR

END










