;-------------------------------------------------------------
;+
; NAME:
;       TIMEWIN
; PURPOSE:
;       Widget based interface for editing various time - parameters
; MAIN PROGRAM:
;       SLAP - program for testing SEISMOLAP
;       SEISMOLAP was developed by Jochen Zschau,
;       Geoforschungszentrum Potsdam, Germany
; CALLING SEQUENCE:
;        TIMEWIN, GROUP=Group,$
;             ALTERED=altered,$
;             INITIALIZE=INITIALIZE,$
;             QUAKE_JS=quake_js,$
;             GRID_DATE=grid_date,$
;             GRID_TIMEWIN=grid_win,$
;             GRID_SHIFT=grid_shift
; INPUTS:
;             GROUP, Specifies Group-Leader of the main base
;             QUAKE_JS, Julian Seconds of the earthquakes
; KEYWORD PARAMETERS:
;             INITIALIZE, Switch on initializing without mapping the base
; OUTPUTS:
;             GRID_DATE, min. and max. possible Julian Second of the epoches
;             GRID_TIMEWIN, Cuts the influence of older earthquakes
;             GRID_SHIFT, Interval between two epoches
; MODIFICATION HISTORY:
;       Matthias Liebetanz, Darmstadt University of Technology, Germany, 19 May 1998.
;
;-
;-------------------------------------------------------------
PRO timewin, GROUP=Group,$
             ALTERED=altered,$
             INITIALIZE=INITIALIZE,$
             QUAKE_JS=quake_js,$
             GRID_DATE=grid_date,$
             GRID_TIMEWIN=grid_win,$
             GRID_SHIFT=grid_shift


  IF N_ELEMENTS(Group) EQ 0 THEN GROUP=0

  junk   = { CW_PDMENU_S, flags:0, name:'' }

IF NOT KEYWORD_SET(GRID_DATE) THEN BEGIN
   win_Years=0L
   win_Months=0L
   win_Days=10L
   win_hours=0L
   win_minutes=0L
   win_seconds=0L
   shift_Years=0L
   shift_Months=0L
   shift_Days=1L
   shift_hours=0L
   shift_minutes=0L
   shift_seconds=0L
   minjs=MIN(quake_js,MAX=maxjs)
   js2ymds,minjs,from_Y,from_M,from_D,Offset_s
   sec2hms,Offset_s,from_hour,from_Min,from_sec
   js2ymds,maxjs,to_Y,to_M,to_D,Offset_s
   sec2hms,Offset_s,to_hour,to_Min,to_sec
   grid_date=DBLARR(2)
   grid_date(0)=minjs
   grid_date(1)=maxjs
   grid_win=ymdhms2s(win_Years,$
                     win_Months,$
                     win_Days,$
                     win_hours,$
                     win_minutes,$
                     win_seconds)
   grid_shift=ymdhms2s(shift_Years,$
                       shift_Months,$
                       shift_Days,$
                       shift_hours,$
                       shift_minutes,$
                       shift_seconds)
ENDIF ELSE BEGIN
   win_Years=LONG(grid_win/977616000.D)
   tmp=grid_win-win_Years*977616000.D
   win_Months=LONG(tmp/2678400.D)
   tmp=tmp-win_Months*2678400.D
   win_Days=LONG(tmp/86400.D)
   tmp=tmp-win_Days*86400.D
   win_hours=LONG(tmp/3600.D)
   tmp=tmp-win_hours*3600.D
   win_minutes=LONG(tmp/60.D)
   tmp=tmp-win_minutes*60.D
   win_seconds=LONG(tmp)
   shift_Years=LONG(grid_shift/977616000.D)
   tmp=grid_shift-shift_Years*977616000.D
   shift_Months=LONG(tmp/2678400.D)
   tmp=tmp-shift_Months*2678400.D
   shift_Days=LONG(tmp/86400.D)
   tmp=tmp-shift_Days*86400.D
   shift_hours=LONG(tmp/3600.D)
   tmp=tmp-shift_hours*3600.D
   shift_minutes=LONG(tmp/60.D)
   tmp=tmp-shift_minutes*60.D
   shift_seconds=LONG(tmp)


   minjs=MIN(quake_js,MAX=maxjs)
   IF minjs GT grid_date(0) THEN grid_date(0) = minjs
   IF maxjs LT grid_date(1) THEN grid_date(1) = maxjs

   js2ymds,grid_date(0),from_Y,from_M,from_D,Offset_s
   sec2hms,Offset_s,from_hour,from_Min,from_sec
   js2ymds,grid_date(1),to_Y,to_M,to_D,Offset_s
   sec2hms,Offset_s,to_hour,to_Min,to_sec
ENDELSE

IF KEYWORD_SET(INITIALIZE) THEN RETURN


grid_date_old=grid_date
grid_win_old=grid_win
grid_shift_old=grid_shift


  MAIN13 = WIDGET_BASE(GROUP_LEADER=Group, $
      COLUMN=1, $
      MAP=1, $
      TITLE='Time Window', $
      UVALUE='MAIN13')

  BASE155 = WIDGET_BASE(MAIN13, $
      COLUMN=1, $
      FRAME=1, $
      MAP=1, $
      TITLE='BASE_DATE', $
      UVALUE='BASE155')

  LABEL388 = WIDGET_LABEL( BASE155, $
      UVALUE='LABEL388', $
      VALUE='Date, Time :')

  BASE404 = WIDGET_BASE(BASE155, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE404')

  LABEL410 = WIDGET_LABEL( BASE404, $
      UVALUE='LABEL410', $
      VALUE='Day', $
      XSIZE=60)

  FieldVal3772 = [ $
    '' ]
  FIELD_FROM_DAY = CW_FIELD( BASE404,VALUE=FieldVal3772, $
      ROW=1, $
      INTEGER=1, $
      TITLE='min', $
      UVALUE='FIELD_FROM_DAY', $
      XSIZE=3)

  FieldVal3774 = [ $
    '' ]
  FIELD_TO_DAY = CW_FIELD( BASE404,VALUE=FieldVal3774, $
      ROW=1, $
      INTEGER=1, $
      TITLE='max', $
      UVALUE='FIELD_TO_DAY', $
      XSIZE=3)


  BASE453 = WIDGET_BASE(BASE155, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE453')

  LABEL450 = WIDGET_LABEL( BASE453, $
      UVALUE='LABEL450', $
      VALUE='Month', $
      XSIZE=60)

  FieldVal3940 = [ $
    '' ]
  FIELD_FROM_MONTH = CW_FIELD( BASE453,VALUE=FieldVal3940, $
      ROW=1, $
      INTEGER=1, $
      TITLE='min', $
      UVALUE='FIELD_FROM_MONTH', $
      XSIZE=3)

  FieldVal3942 = [ $
    '' ]
  FIELD_TO_MONTH = CW_FIELD( BASE453,VALUE=FieldVal3942, $
      ROW=1, $
      INTEGER=1, $
      TITLE='max', $
      UVALUE='FIELD_TO_MONTH', $
      XSIZE=3)


  BASE457 = WIDGET_BASE(BASE155, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE457')

  LABEL454 = WIDGET_LABEL( BASE457, $
      UVALUE='LABEL454', $
      VALUE='Year', $
      XSIZE=60)

  FieldVal3946 = [ $
    '' ]
  FIELD_FROM_YEAR = CW_FIELD( BASE457,VALUE=FieldVal3946, $
      ROW=1, $
      INTEGER=1, $
      TITLE='min', $
      UVALUE='FIELD_FROM_YEAR', $
      XSIZE=6)

  FieldVal3948 = [ $
    '' ]
  FIELD_TO_YEAR = CW_FIELD( BASE457,VALUE=FieldVal3948, $
      ROW=1, $
      INTEGER=1, $
      TITLE='max', $
      UVALUE='FIELD_TO_YEAR', $
      XSIZE=6)


  BASE417 = WIDGET_BASE(BASE155, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE417')

  LABEL435 = WIDGET_LABEL( BASE417, $
      UVALUE='LABEL435', $
      VALUE='Hour', $
      XSIZE=60)

  FieldVal3778 = [ $
    '' ]
  FIELD_FROM_HOUR = CW_FIELD( BASE417,VALUE=FieldVal3778, $
      ROW=1, $
      INTEGER=1, $
      TITLE='min', $
      UVALUE='FIELD_FROM_HOUR', $
      XSIZE=3)

  FieldVal3780 = [ $
    '' ]
  FIELD_TO_HOUR = CW_FIELD( BASE417,VALUE=FieldVal3780, $
      ROW=1, $
      INTEGER=1, $
      TITLE='max', $
      UVALUE='FIELD_TO_HOUR', $
      XSIZE=3)


  BASE418 = WIDGET_BASE(BASE155, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE418')

  LABEL437 = WIDGET_LABEL( BASE418, $
      UVALUE='LABEL437', $
      VALUE='Minute', $
      XSIZE=60)

  FieldVal3784 = [ $
    '' ]
  FIELD_FROM_MINUTE = CW_FIELD( BASE418,VALUE=FieldVal3784, $
      ROW=1, $
      INTEGER=1, $
      TITLE='min', $
      UVALUE='FIELD_FROM_MINUTE', $
      XSIZE=3)

  FieldVal3786 = [ $
    '' ]
  FIELD_TO_MINUTE = CW_FIELD( BASE418,VALUE=FieldVal3786, $
      ROW=1, $
      INTEGER=1, $
      TITLE='max', $
      UVALUE='FIELD_TO_MINUTE', $
      XSIZE=3)


  BASE425 = WIDGET_BASE(BASE155, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE425')

  LABEL439 = WIDGET_LABEL( BASE425, $
      UVALUE='LABEL439', $
      VALUE='Second', $
      XSIZE=60)

  FieldVal3790 = [ $
    '' ]
  FIELD_FROM_SEC = CW_FIELD( BASE425,VALUE=FieldVal3790, $
      ROW=1, $
      INTEGER=1, $
      TITLE='min', $
      UVALUE='FIELD_FROM_SEC', $
      XSIZE=3)

  FieldVal3792 = [ $
    '' ]
  FIELD_TO_SEC = CW_FIELD( BASE425,VALUE=FieldVal3792, $
      ROW=1, $
      INTEGER=1, $
      TITLE='max', $
      UVALUE='FIELD_TO_SEC', $
      XSIZE=3)

  BASE521 = WIDGET_BASE(MAIN13, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE521')

  BASE280 = WIDGET_BASE(BASE521, $
      COLUMN=1, $
      FRAME=1, $
      MAP=1, $
      TITLE='BASE_TIME_WINDOW', $
      UVALUE='BASE280')


  LABEL392 = WIDGET_LABEL( BASE280, $
      UVALUE='LABEL392', $
      VALUE='Time Window :')

  BASE373 = WIDGET_BASE(BASE280, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE373')

  LABEL371 = WIDGET_LABEL( BASE373, $
      UVALUE='LABEL371', $
      VALUE='Years', $
      XSIZE=60)

  FieldVal240 = [ $
    '0' ]
  FIELD_WINDOW_YEARS = CW_FIELD( BASE373,VALUE=FieldVal240, $
      ROW=1, $
      LONG=1, $
      TITLE=' ', $
      UVALUE='FIELD_WINDOW_YEARS', $
      XSIZE=10)


  BASE370 = WIDGET_BASE(BASE280, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE370')

  LABEL368 = WIDGET_LABEL( BASE370, $
      UVALUE='LABEL368', $
      VALUE='Months', $
      XSIZE=60)

  FieldVal244 = [ $
    '0' ]
  FIELD_WINDOW_MONTHS = CW_FIELD( BASE370,VALUE=FieldVal244, $
      ROW=1, $
      LONG=1, $
      TITLE=' ', $
      UVALUE='FIELD_WINDOW_MONTHS', $
      XSIZE=10)


  BASE367 = WIDGET_BASE(BASE280, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE367')

  LABEL365 = WIDGET_LABEL( BASE367, $
      UVALUE='LABEL365', $
      VALUE='Days', $
      XSIZE=60)

  FieldVal248 = [ $
    '0' ]
  FIELD_WINDOW_DAYS = CW_FIELD( BASE367,VALUE=FieldVal248, $
      ROW=1, $
      LONG=1, $
      TITLE=' ', $
      UVALUE='FIELD_WINDOW_DAYS', $
      XSIZE=10)


  BASE364 = WIDGET_BASE(BASE280, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE364')

  LABEL362 = WIDGET_LABEL( BASE364, $
      UVALUE='LABEL362', $
      VALUE='Hours', $
      XSIZE=60)

  FieldVal252 = [ $
    '0' ]
  FIELD_WINDOW_HOURS = CW_FIELD( BASE364,VALUE=FieldVal252, $
      ROW=1, $
      LONG=1, $
      TITLE=' ', $
      UVALUE='FIELD_WINDOW_HOURS', $
      XSIZE=10)


  BASE361 = WIDGET_BASE(BASE280, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE361')

  LABEL359 = WIDGET_LABEL( BASE361, $
      UVALUE='LABEL359', $
      VALUE='Minutes', $
      XSIZE=60)

  FieldVal256 = [ $
    '0' ]
  FIELD_WINDOW_MINUTES = CW_FIELD( BASE361,VALUE=FieldVal256, $
      ROW=1, $
      LONG=1, $
      TITLE=' ', $
      UVALUE='FIELD_WINDOW_MINUTES', $
      XSIZE=10)


  BASE358 = WIDGET_BASE(BASE280, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE358')

  LABEL356 = WIDGET_LABEL( BASE358, $
      UVALUE='LABEL356', $
      VALUE='Seconds', $
      XSIZE=60)

  FieldVal260 = [ $
    '0' ]
  FIELD_WINDOW_SECONDS = CW_FIELD( BASE358,VALUE=FieldVal260, $
      ROW=1, $
      LONG=1, $
      TITLE=' ', $
      UVALUE='FIELD_WINDOW_SECONDS', $
      XSIZE=10)

  BASE620 = WIDGET_BASE(BASE521, $
      COLUMN=1, $
      FRAME=1, $
      MAP=1, $
      TITLE='BASE_TIME_SHIFT', $
      UVALUE='BASE620')

  LABEL607 = WIDGET_LABEL( BASE620, $
      UVALUE='LABEL607', $
      VALUE='Time shift :')

  BASE373 = WIDGET_BASE(BASE620, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE373')

  LABEL608 = WIDGET_LABEL( BASE373, $
      UVALUE='LABEL608', $
      VALUE='Years', $
      XSIZE=60)

  FieldVal172 = [ $
    '0' ]
  FIELD_SHIFT_YEARS = CW_FIELD( BASE373,VALUE=FieldVal172, $
      ROW=1, $
      LONG=1, $
      TITLE=' ', $
      UVALUE='FIELD_SHIFT_YEARS', $
      XSIZE=10)


  BASE370 = WIDGET_BASE(BASE620, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE370')

  LABEL610 = WIDGET_LABEL( BASE370, $
      UVALUE='LABEL610', $
      VALUE='Months', $
      XSIZE=60)

  FieldVal176 = [ $
    '0' ]
  FIELD_SHIFT_MONTHS = CW_FIELD( BASE370,VALUE=FieldVal176, $
      ROW=1, $
      LONG=1, $
      TITLE=' ', $
      UVALUE='FIELD_SHIFT_MONTHS', $
      XSIZE=10)


  BASE367 = WIDGET_BASE(BASE620, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE367')

  LABEL612 = WIDGET_LABEL( BASE367, $
      UVALUE='LABEL612', $
      VALUE='Days', $
      XSIZE=60)

  FieldVal180 = [ $
    '0' ]
  FIELD_SHIFT_DAYS = CW_FIELD( BASE367,VALUE=FieldVal180, $
      ROW=1, $
      LONG=1, $
      TITLE=' ', $
      UVALUE='FIELD_SHIFT_DAYS', $
      XSIZE=10)


  BASE364 = WIDGET_BASE(BASE620, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE364')

  LABEL614 = WIDGET_LABEL( BASE364, $
      UVALUE='LABEL614', $
      VALUE='Hours', $
      XSIZE=60)

  FieldVal184 = [ $
    '0' ]
  FIELD_SHIFT_HOURS = CW_FIELD( BASE364,VALUE=FieldVal184, $
      ROW=1, $
      LONG=1, $
      TITLE=' ', $
      UVALUE='FIELD_SHIFT_HOURS', $
      XSIZE=10)


  BASE361 = WIDGET_BASE(BASE620, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE361')

  LABEL616 = WIDGET_LABEL( BASE361, $
      UVALUE='LABEL616', $
      VALUE='Minutes', $
      XSIZE=60)

  FieldVal188 = [ $
    '0' ]
  FIELD_SHIFT_MINUTES = CW_FIELD( BASE361,VALUE=FieldVal188, $
      ROW=1, $
      LONG=1, $
      TITLE=' ', $
      UVALUE='FIELD_SHIFT_MINUTES', $
      XSIZE=10)


  BASE358 = WIDGET_BASE(BASE620, $
      ROW=1, $
      MAP=1, $
      UVALUE='BASE358')

  LABEL618 = WIDGET_LABEL( BASE358, $
      UVALUE='LABEL618', $
      VALUE='Seconds', $
      XSIZE=60)

  FieldVal192 = [ $
    '0' ]
  FIELD_SHIFT_SECONDS = CW_FIELD( BASE358,VALUE=FieldVal192, $
      ROW=1, $
      LONG=1, $
      TITLE=' ', $
      UVALUE='FIELD_SHIFT_SECONDS', $
      XSIZE=10)

  LABEL283 = WIDGET_LABEL( MAIN13, $
      UVALUE='LABEL283', $
      VALUE='')

  BUTTON189 = WIDGET_BUTTON( MAIN13, $
      UVALUE='BUTTON_CANCEL', $
      VALUE='Cancel')

  BUTTON180 = WIDGET_BUTTON( MAIN13, $
      UVALUE='BUTTON_OK', $
      VALUE='Ok')


   WIDGET_CONTROL,FIELD_FROM_DAY,SET_VALUE=from_D
   WIDGET_CONTROL,FIELD_FROM_MONTH,SET_VALUE=from_M
   WIDGET_CONTROL,FIELD_FROM_YEAR,SET_VALUE=from_Y
   WIDGET_CONTROL,FIELD_FROM_HOUR,SET_VALUE=from_hour
   WIDGET_CONTROL,FIELD_FROM_MINUTE,SET_VALUE=from_min
   WIDGET_CONTROL,FIELD_FROM_SEC,SET_VALUE=from_sec
   WIDGET_CONTROL,FIELD_TO_DAY,SET_VALUE=to_D
   WIDGET_CONTROL,FIELD_TO_MONTH,SET_VALUE=to_M
   WIDGET_CONTROL,FIELD_TO_YEAR,SET_VALUE=to_Y
   WIDGET_CONTROL,FIELD_TO_HOUR,SET_VALUE=to_hour
   WIDGET_CONTROL,FIELD_TO_MINUTE,SET_VALUE=to_min
   WIDGET_CONTROL,FIELD_TO_SEC,SET_VALUE=to_sec
   WIDGET_CONTROL,FIELD_WINDOW_YEARS,SET_VALUE=win_Years
   WIDGET_CONTROL,FIELD_WINDOW_MONTHS,SET_VALUE=win_Months
   WIDGET_CONTROL,FIELD_WINDOW_DAYS,SET_VALUE=win_Days
   WIDGET_CONTROL,FIELD_WINDOW_HOURS,SET_VALUE=win_hours
   WIDGET_CONTROL,FIELD_WINDOW_MINUTES,SET_VALUE=win_minutes
   WIDGET_CONTROL,FIELD_WINDOW_SECONDS,SET_VALUE=win_seconds
   WIDGET_CONTROL,FIELD_SHIFT_YEARS,SET_VALUE=shift_Years
   WIDGET_CONTROL,FIELD_SHIFT_MONTHS,SET_VALUE=shift_Months
   WIDGET_CONTROL,FIELD_SHIFT_DAYS,SET_VALUE=shift_Days
   WIDGET_CONTROL,FIELD_SHIFT_HOURS,SET_VALUE=shift_hours
   WIDGET_CONTROL,FIELD_SHIFT_MINUTES,SET_VALUE=shift_minutes
   WIDGET_CONTROL,FIELD_SHIFT_SECONDS,SET_VALUE=shift_seconds


Ev=''

IF KEYWORD_SET(INITIALIZE) THEN GOTO,timewin_save

WIDGET_CONTROL, MAIN13, /REALIZE

WHILE (Ev NE 'BUTTON_OK') AND (Ev NE 'BUTTON_CANCEL') DO BEGIN

Event=WIDGET_EVENT(MAIN13)

  WIDGET_CONTROL,Event.Id,GET_UVALUE=Ev

  CASE Ev OF

  'BUTTON_CANCEL': BEGIN
      END
  'BUTTON_OK': BEGIN
      END
  ENDCASE

ENDWHILE

timewin_save:

IF Ev EQ 'BUTTON_OK' THEN BEGIN

   WIDGET_CONTROL,FIELD_FROM_DAY,GET_VALUE=from_D
   WIDGET_CONTROL,FIELD_FROM_MONTH,GET_VALUE=from_M
   WIDGET_CONTROL,FIELD_FROM_YEAR,GET_VALUE=from_Y
   WIDGET_CONTROL,FIELD_FROM_HOUR,GET_VALUE=from_hour
   WIDGET_CONTROL,FIELD_FROM_MINUTE,GET_VALUE=from_min
   WIDGET_CONTROL,FIELD_FROM_SEC,GET_VALUE=from_sec
   WIDGET_CONTROL,FIELD_TO_DAY,GET_VALUE=to_D
   WIDGET_CONTROL,FIELD_TO_MONTH,GET_VALUE=to_M
   WIDGET_CONTROL,FIELD_TO_YEAR,GET_VALUE=to_Y
   WIDGET_CONTROL,FIELD_TO_HOUR,GET_VALUE=to_hour
   WIDGET_CONTROL,FIELD_TO_MINUTE,GET_VALUE=to_min
   WIDGET_CONTROL,FIELD_TO_SEC,GET_VALUE=to_sec
   WIDGET_CONTROL,FIELD_WINDOW_YEARS,GET_VALUE=win_Years
   WIDGET_CONTROL,FIELD_WINDOW_MONTHS,GET_VALUE=win_Months
   WIDGET_CONTROL,FIELD_WINDOW_DAYS,GET_VALUE=win_Days
   WIDGET_CONTROL,FIELD_WINDOW_HOURS,GET_VALUE=win_hours
   WIDGET_CONTROL,FIELD_WINDOW_MINUTES,GET_VALUE=win_minutes
   WIDGET_CONTROL,FIELD_WINDOW_SECONDS,GET_VALUE=win_seconds
   WIDGET_CONTROL,FIELD_SHIFT_YEARS,GET_VALUE=shift_Years
   WIDGET_CONTROL,FIELD_SHIFT_MONTHS,GET_VALUE=shift_Months
   WIDGET_CONTROL,FIELD_SHIFT_DAYS,GET_VALUE=shift_Days
   WIDGET_CONTROL,FIELD_SHIFT_HOURS,GET_VALUE=shift_hours
   WIDGET_CONTROL,FIELD_SHIFT_MINUTES,GET_VALUE=shift_minutes
   WIDGET_CONTROL,FIELD_SHIFT_SECONDS,GET_VALUE=shift_seconds

   grid_date(0)=YMDS2JS(from_Y, $
                   from_M, $
                   from_D, $
                   from_hour*3600.+from_min*60.+from_sec)


   grid_date(1)=YMDS2JS(to_Y, $
                 to_M, $
                 to_D, $
                 to_hour*3600.+to_min*60.+to_sec)

   grid_win=ymdhms2s(win_Years,$
                     win_Months,$
                     win_Days,$
                     win_hours,$
                     win_minutes,$
                     win_seconds)

   grid_shift=ymdhms2s(shift_Years,$
                       shift_Months,$
                       shift_Days,$
                       shift_hours,$
                       shift_minutes,$
                       shift_seconds)

  IF (grid_date(0) NE grid_date_old(0)) OR $
     (grid_date(1) NE grid_date_old(1)) OR $
     (grid_win NE grid_win_old) OR $
     (grid_shift NE grid_shift_old) $
  THEN altered=1 ELSE altered=0

ENDIF ELSE altered=0

WIDGET_CONTROL,MAIN13,/DEST

END
